
# Overview

`lawyer` is python library for argument parsing as efficiently as possible and uses a custom linked list type
data structure to create nested argument groups. Allows any argument notation to be used (intermixed too) which
is a fresh look from the traditional `--` and `-` prefixes to identify arguments.

**A proper documentation will be available at _[d33p0st.in](https://d33p0st.in)_ at a later stage in the development phase. As of now all code has
doc-strings for help.**
